pub struct Humidity(/* private fields */);Expand description
A humidity reading
Implementations
Sourceimpl Humidity
impl Humidity
Sourcepub fn as_raw(&self) -> u16
pub fn as_raw(&self) -> u16
Returns the humidity reading exactly as read from the sensor, with the status bits cleared
Sourcepub fn as_percent_relative(&self) -> f32
pub fn as_percent_relative(&self) -> f32
Converts the temperature reading into percent relative humidity (0.0 = 0%, 100.0 = 100%) and clamps it to the 0%-100% range
This function uses single-precision floating-point operations.